autofocus property
Whether this math field should focus itself if nothing else is already focused.
If true, the keyboard will open as soon as this math field obtains
focus. Otherwise, the keyboard is only shown after the user taps the math
field.
Defaults to false. Cannot be null.
Implementation
final bool autofocus;